# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cohesivenet.exceptions import ApiTypeError, ApiValueError


class IPsecApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def delete_ipsec_endpoint(self, endpoint_id, **kwargs):  # noqa: E501
        """delete_ipsec_endpoint  # noqa: E501

        Delete IPsec endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ipsec_endpoint(endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_ipsec_endpoint_with_http_info(
            endpoint_id, **kwargs
        )  # noqa: E501

    def delete_ipsec_endpoint_with_http_info(self, endpoint_id, **kwargs):  # noqa: E501
        """delete_ipsec_endpoint  # noqa: E501

        Delete IPsec endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ipsec_endpoint_with_http_info(endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["endpoint_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ipsec_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `delete_ipsec_endpoint`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `delete_ipsec_endpoint`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_ipsec_endpoint_tunnel(
        self, endpoint_id, tunnel_id, **kwargs
    ):  # noqa: E501
        """delete_ipsec_endpoint_tunnel  # noqa: E501

        Delete IPsec tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ipsec_endpoint_tunnel(endpoint_id, tunnel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param int tunnel_id: ID for tunnel (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_ipsec_endpoint_tunnel_with_http_info(
            endpoint_id, tunnel_id, **kwargs
        )  # noqa: E501

    def delete_ipsec_endpoint_tunnel_with_http_info(
        self, endpoint_id, tunnel_id, **kwargs
    ):  # noqa: E501
        """delete_ipsec_endpoint_tunnel  # noqa: E501

        Delete IPsec tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ipsec_endpoint_tunnel_with_http_info(endpoint_id, tunnel_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param int tunnel_id: ID for tunnel (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["endpoint_id", "tunnel_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ipsec_endpoint_tunnel" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `delete_ipsec_endpoint_tunnel`"
            )  # noqa: E501
        # verify the required parameter 'tunnel_id' is set
        if "tunnel_id" not in local_var_params or local_var_params["tunnel_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `tunnel_id` when calling `delete_ipsec_endpoint_tunnel`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `delete_ipsec_endpoint_tunnel`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501
        if "tunnel_id" in local_var_params:
            path_params["tunnel_id"] = local_var_params["tunnel_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}/tunnels/{tunnel_id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ipsec(self, **kwargs):  # noqa: E501
        """get_ipsec  # noqa: E501

        Get details for all IPsec endpoints/subnets  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: IpsecSystemDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ipsec_with_http_info(**kwargs)  # noqa: E501

    def get_ipsec_with_http_info(self, **kwargs):  # noqa: E501
        """get_ipsec  # noqa: E501

        Get details for all IPsec endpoints/subnets  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(IpsecSystemDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ipsec" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="IpsecSystemDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ipsec_endpoint(self, endpoint_id, **kwargs):  # noqa: E501
        """get_ipsec_endpoint  # noqa: E501

        Get IPsec endpoint information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec_endpoint(endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ipsec_endpoint_with_http_info(
            endpoint_id, **kwargs
        )  # noqa: E501

    def get_ipsec_endpoint_with_http_info(self, endpoint_id, **kwargs):  # noqa: E501
        """get_ipsec_endpoint  # noqa: E501

        Get IPsec endpoint information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec_endpoint_with_http_info(endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["endpoint_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ipsec_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `get_ipsec_endpoint`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `get_ipsec_endpoint`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_ipsec_status(self, **kwargs):  # noqa: E501
        """get_ipsec_status  # noqa: E501

        Describe ipsec tunnels status  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: IpsecTunnelListResponseKeyValue
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_ipsec_status_with_http_info(**kwargs)  # noqa: E501

    def get_ipsec_status_with_http_info(self, **kwargs):  # noqa: E501
        """get_ipsec_status  # noqa: E501

        Describe ipsec tunnels status  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ipsec_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(IpsecTunnelListResponseKeyValue, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ipsec_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/status/ipsec",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="IpsecTunnelListResponseKeyValue",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_link_history(self, **kwargs):  # noqa: E501
        """get_link_history  # noqa: E501

        Provides information about the connection history of the subnet or tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_link_history(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str remote: Address string in CIDR format to display link history to a remote endpoint.
        :param str local: Address string in CIDR format which will display status of the local route
        :param int tunnelid: Will display link history of just the tunnel specified, which may be only one tunnel to a remote endpoint.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: LinkHistoryDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_link_history_with_http_info(**kwargs)  # noqa: E501

    def get_link_history_with_http_info(self, **kwargs):  # noqa: E501
        """get_link_history  # noqa: E501

        Provides information about the connection history of the subnet or tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_link_history_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str remote: Address string in CIDR format to display link history to a remote endpoint.
        :param str local: Address string in CIDR format which will display status of the local route
        :param int tunnelid: Will display link history of just the tunnel specified, which may be only one tunnel to a remote endpoint.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(LinkHistoryDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["remote", "local", "tunnelid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_link_history" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "remote" in local_var_params:
            query_params.append(("remote", local_var_params["remote"]))  # noqa: E501
        if "local" in local_var_params:
            query_params.append(("local", local_var_params["local"]))  # noqa: E501
        if "tunnelid" in local_var_params:
            query_params.append(
                ("tunnelid", local_var_params["tunnelid"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/status/link_history",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="LinkHistoryDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_ipsec_endpoint(
        self, create_ipsec_endpoint_request, **kwargs
    ):  # noqa: E501
        """post_create_ipsec_endpoint  # noqa: E501

        Create IPsec connection to the defined remote gateway  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_ipsec_endpoint(create_ipsec_endpoint_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateIpsecEndpointRequest create_ipsec_endpoint_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: IpsecRemoteEndpointDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_ipsec_endpoint_with_http_info(
            create_ipsec_endpoint_request, **kwargs
        )  # noqa: E501

    def post_create_ipsec_endpoint_with_http_info(
        self, create_ipsec_endpoint_request, **kwargs
    ):  # noqa: E501
        """post_create_ipsec_endpoint  # noqa: E501

        Create IPsec connection to the defined remote gateway  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_ipsec_endpoint_with_http_info(create_ipsec_endpoint_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateIpsecEndpointRequest create_ipsec_endpoint_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(IpsecRemoteEndpointDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["create_ipsec_endpoint_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_ipsec_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'create_ipsec_endpoint_request' is set
        if (
            "create_ipsec_endpoint_request" not in local_var_params
            or local_var_params["create_ipsec_endpoint_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `create_ipsec_endpoint_request` when calling `post_create_ipsec_endpoint`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_ipsec_endpoint_request" in local_var_params:
            body_params = local_var_params["create_ipsec_endpoint_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="IpsecRemoteEndpointDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_ipsec_endpoint_tunnel(
        self, endpoint_id, create_ipsec_tunnel_request, **kwargs
    ):  # noqa: E501
        """post_create_ipsec_endpoint_tunnel  # noqa: E501

        Create IPsec endpoint tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_ipsec_endpoint_tunnel(endpoint_id, create_ipsec_tunnel_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param CreateIpsecTunnelRequest create_ipsec_tunnel_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_ipsec_endpoint_tunnel_with_http_info(
            endpoint_id, create_ipsec_tunnel_request, **kwargs
        )  # noqa: E501

    def post_create_ipsec_endpoint_tunnel_with_http_info(
        self, endpoint_id, create_ipsec_tunnel_request, **kwargs
    ):  # noqa: E501
        """post_create_ipsec_endpoint_tunnel  # noqa: E501

        Create IPsec endpoint tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_ipsec_endpoint_tunnel_with_http_info(endpoint_id, create_ipsec_tunnel_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param CreateIpsecTunnelRequest create_ipsec_tunnel_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["endpoint_id", "create_ipsec_tunnel_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_ipsec_endpoint_tunnel" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `post_create_ipsec_endpoint_tunnel`"
            )  # noqa: E501
        # verify the required parameter 'create_ipsec_tunnel_request' is set
        if (
            "create_ipsec_tunnel_request" not in local_var_params
            or local_var_params["create_ipsec_tunnel_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `create_ipsec_tunnel_request` when calling `post_create_ipsec_endpoint_tunnel`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `post_create_ipsec_endpoint_tunnel`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_ipsec_tunnel_request" in local_var_params:
            body_params = local_var_params["create_ipsec_tunnel_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}/tunnels",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_restart_ipsec_action(self, restart_request, **kwargs):  # noqa: E501
        """post_restart_ipsec_action  # noqa: E501

        Restart ipsec subystem  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_restart_ipsec_action(restart_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RestartRequest restart_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RestartStatus
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_restart_ipsec_action_with_http_info(
            restart_request, **kwargs
        )  # noqa: E501

    def post_restart_ipsec_action_with_http_info(
        self, restart_request, **kwargs
    ):  # noqa: E501
        """post_restart_ipsec_action  # noqa: E501

        Restart ipsec subystem  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_restart_ipsec_action_with_http_info(restart_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RestartRequest restart_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RestartStatus, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["restart_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_restart_ipsec_action" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'restart_request' is set
        if (
            "restart_request" not in local_var_params
            or local_var_params["restart_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `restart_request` when calling `post_restart_ipsec_action`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "restart_request" in local_var_params:
            body_params = local_var_params["restart_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RestartStatus",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_edit_ipsec_endpoint(
        self, endpoint_id, update_ipsec_connection_request, **kwargs
    ):  # noqa: E501
        """put_edit_ipsec_endpoint  # noqa: E501

        Edit IPsec connection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_ipsec_endpoint(endpoint_id, update_ipsec_connection_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param UpdateIpsecConnectionRequest update_ipsec_connection_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_edit_ipsec_endpoint_with_http_info(
            endpoint_id, update_ipsec_connection_request, **kwargs
        )  # noqa: E501

    def put_edit_ipsec_endpoint_with_http_info(
        self, endpoint_id, update_ipsec_connection_request, **kwargs
    ):  # noqa: E501
        """put_edit_ipsec_endpoint  # noqa: E501

        Edit IPsec connection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_ipsec_endpoint_with_http_info(endpoint_id, update_ipsec_connection_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param UpdateIpsecConnectionRequest update_ipsec_connection_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["endpoint_id", "update_ipsec_connection_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_edit_ipsec_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `put_edit_ipsec_endpoint`"
            )  # noqa: E501
        # verify the required parameter 'update_ipsec_connection_request' is set
        if (
            "update_ipsec_connection_request" not in local_var_params
            or local_var_params["update_ipsec_connection_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_ipsec_connection_request` when calling `put_edit_ipsec_endpoint`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `put_edit_ipsec_endpoint`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_ipsec_connection_request" in local_var_params:
            body_params = local_var_params["update_ipsec_connection_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_edit_ipsec_endpoint_tunnel(
        self, endpoint_id, tunnel_id, update_ipsec_tunnel_request, **kwargs
    ):  # noqa: E501
        """put_edit_ipsec_endpoint_tunnel  # noqa: E501

        Edit IPsec endpoint tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_ipsec_endpoint_tunnel(endpoint_id, tunnel_id, update_ipsec_tunnel_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param int tunnel_id: ID for tunnel (required)
        :param UpdateIpsecTunnelRequest update_ipsec_tunnel_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: IpsecTunnelDetail
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_edit_ipsec_endpoint_tunnel_with_http_info(
            endpoint_id, tunnel_id, update_ipsec_tunnel_request, **kwargs
        )  # noqa: E501

    def put_edit_ipsec_endpoint_tunnel_with_http_info(
        self, endpoint_id, tunnel_id, update_ipsec_tunnel_request, **kwargs
    ):  # noqa: E501
        """put_edit_ipsec_endpoint_tunnel  # noqa: E501

        Edit IPsec endpoint tunnel  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_ipsec_endpoint_tunnel_with_http_info(endpoint_id, tunnel_id, update_ipsec_tunnel_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int endpoint_id: ID for IPsec endpoint (required)
        :param int tunnel_id: ID for tunnel (required)
        :param UpdateIpsecTunnelRequest update_ipsec_tunnel_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(IpsecTunnelDetail, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            "endpoint_id",
            "tunnel_id",
            "update_ipsec_tunnel_request",
        ]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_edit_ipsec_endpoint_tunnel" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'endpoint_id' is set
        if (
            "endpoint_id" not in local_var_params
            or local_var_params["endpoint_id"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `endpoint_id` when calling `put_edit_ipsec_endpoint_tunnel`"
            )  # noqa: E501
        # verify the required parameter 'tunnel_id' is set
        if "tunnel_id" not in local_var_params or local_var_params["tunnel_id"] is None:
            raise ApiValueError(
                "Missing the required parameter `tunnel_id` when calling `put_edit_ipsec_endpoint_tunnel`"
            )  # noqa: E501
        # verify the required parameter 'update_ipsec_tunnel_request' is set
        if (
            "update_ipsec_tunnel_request" not in local_var_params
            or local_var_params["update_ipsec_tunnel_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_ipsec_tunnel_request` when calling `put_edit_ipsec_endpoint_tunnel`"
            )  # noqa: E501

        if (
            "endpoint_id" in local_var_params and local_var_params["endpoint_id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `endpoint_id` when calling `put_edit_ipsec_endpoint_tunnel`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "endpoint_id" in local_var_params:
            path_params["endpoint_id"] = local_var_params["endpoint_id"]  # noqa: E501
        if "tunnel_id" in local_var_params:
            path_params["tunnel_id"] = local_var_params["tunnel_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_ipsec_tunnel_request" in local_var_params:
            body_params = local_var_params["update_ipsec_tunnel_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec/endpoints/{endpoint_id}/tunnels/{tunnel_id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="IpsecTunnelDetail",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_ipsec_config(self, update_ipsec_address_request, **kwargs):  # noqa: E501
        """put_ipsec_config  # noqa: E501

        Edit Ipsec Configuration on device. Note, This is device wide and must be set before  any remote endpoint definitions are created. If it needs to be changed, all remote endpoint  information and tunnel information must be deleted first.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ipsec_config(update_ipsec_address_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateIpsecAddressRequest update_ipsec_address_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_ipsec_config_with_http_info(
            update_ipsec_address_request, **kwargs
        )  # noqa: E501

    def put_ipsec_config_with_http_info(
        self, update_ipsec_address_request, **kwargs
    ):  # noqa: E501
        """put_ipsec_config  # noqa: E501

        Edit Ipsec Configuration on device. Note, This is device wide and must be set before  any remote endpoint definitions are created. If it needs to be changed, all remote endpoint  information and tunnel information must be deleted first.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_ipsec_config_with_http_info(update_ipsec_address_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateIpsecAddressRequest update_ipsec_address_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_ipsec_address_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_ipsec_config" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_ipsec_address_request' is set
        if (
            "update_ipsec_address_request" not in local_var_params
            or local_var_params["update_ipsec_address_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_ipsec_address_request` when calling `put_ipsec_config`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_ipsec_address_request" in local_var_params:
            body_params = local_var_params["update_ipsec_address_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/ipsec",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

from tests.rest_mock import RestClientMock

from cohesivenet import VNS3Client, models, Configuration
from cohesivenet.rest import ApiException


class TestConfigurationApi(object):
    """
    ConfigurationApi unit test stubs
    
    Under test: cohesivenet.api.vns3.configuration_api.ConfigurationApi
    """

    def test_get_config(self, rest_mock: RestClientMock):
        """Test case for get_config
        """
        rest_mock.stub_request(
            "get",
            "/api/config",
            {
                "response": {
                    "asn": None,
                    "licensed": False,
                    "manager_id": None,
                    "ntp_hosts": "0.ubuntu.pool.ntp.org 1.ubuntu.pool.ntp.org "
                    "2.ubuntu.pool.ntp.org 3.ubuntu.pool.ntp.org "
                    "ntp.ubuntu.com time.apple.com",
                    "overlay_ipaddress": None,
                    "peered": None,
                    "private_ipaddress": "10.0.1.56",
                    "public_ipaddress": "3.86.152.210",
                    "security_token": None,
                    "topology_checksum": "fdae64751d4090aee13b8a26c5890eef7f75dc82",
                    "topology_name": None,
                    "vns3_version": "4.8.3-20190926",
                }
            },
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.get_config()
        assert type(resp) is models.ConfigDetail
        assert resp.response.licensed is False
        assert (
            resp.response.topology_checksum
            == "fdae64751d4090aee13b8a26c5890eef7f75dc82"
        )

    def test_get_config(self, rest_mock: RestClientMock):
        """Test case for get_config

        """
        rest_mock.stub_request(
            "get",
            "/api/config",
            {
                "response": {
                    "asn": None,
                    "licensed": False,
                    "manager_id": None,
                    "ntp_hosts": "0.ubuntu.pool.ntp.org 1.ubuntu.pool.ntp.org "
                    "2.ubuntu.pool.ntp.org 3.ubuntu.pool.ntp.org "
                    "ntp.ubuntu.com time.apple.com",
                    "overlay_ipaddress": None,
                    "peered": None,
                    "private_ipaddress": "10.0.1.56",
                    "public_ipaddress": "3.86.152.210",
                    "security_token": None,
                    "topology_checksum": "fdae64751d4090aee13b8a26c5890eef7f75dc82",
                    "topology_name": None,
                    "vns3_version": "4.8.3-20190926",
                }
            },
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.get_config()
        assert type(resp) is models.ConfigDetail
        assert resp.response.licensed is False
        assert (
            resp.response.topology_checksum
            == "fdae64751d4090aee13b8a26c5890eef7f75dc82"
        )

    def test_get_keyset_unlicensed(self, rest_mock: RestClientMock):
        """Test case for get_keyset

        """
        rest_mock.stub_request("get", "/api/keyset", {"response": None})

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.get_keyset()
        assert type(resp) is models.KeysetDetail
        assert resp.response is None

    @pytest.mark.licensed
    def test_get_keyset(self, rest_mock: RestClientMock):
        """Test case for get_keyset

        """
        rest_mock.stub_request("get", "/api/keyset", {"response": None})

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.get_keyset()
        assert type(resp) is models.KeysetDetail
        assert resp.response is None

    def test_get_runtime(self, rest_mock: RestClientMock):
        """Test case for get_runtime
        """
        rest_mock.stub_request(
            "get",
            "/api/runtime",
            {
                "response": {
                    "private_ipaddress": "10.0.1.37",
                    "licensed": False,
                    "vns3_version": "4.8.3-20190926",
                    "public_ipaddress": "3.226.87.19",
                    "ntp_hosts": "0.ubuntu.pool.ntp.org 1.ubuntu.pool.ntp.org 2.ubuntu.pool.ntp.org 3.ubuntu.pool.ntp.org ntp.ubuntu.com time.apple.com",
                    "topology_checksum": "1c58f209db234f8b276964764ac81a7864a55c8d",
                }
            },
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.get_runtime()
        assert type(resp) is models.ConfigDetail
        assert resp.response.private_ipaddress == "10.0.1.37"

    @pytest.mark.skip(reason="Todo - INSTALL SSL")
    @pytest.mark.licensed
    def test_get_ssl_install_status(self, rest_mock: RestClientMock):
        """Test case for get_ssl_install_status

        """
        pass

    def test_put_config(self, rest_mock: RestClientMock):
        """Test case for put_config

        """
        pass

    @pytest.mark.skip(reason="Todo - INSTALL SSL")
    @pytest.mark.licensed
    def test_put_install_ssl_keypair(self, rest_mock: RestClientMock):
        """Test case for put_install_ssl_keypair

        """
        pass

    def test_put_keyset(self, rest_mock: RestClientMock):
        """Test case for put_keyset

        """
        pass

    def test_put_update_admin_ui(self, rest_mock: RestClientMock):
        """Test case for put_update_admin_ui

        """
        method, uri = "put", "/api/admin_ui"
        request = {
            "enabled": True,
            "admin_username": "vnscubed",
            "admin_password": "fakepass1234",
        }
        rest_mock.stub_request(
            method,
            uri,
            {
                "response": {
                    "admin_password": None,
                    "admin_username": None,
                    "enabled": True,
                }
            },
        )

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.put_update_admin_ui(request)
        assert type(resp) is models.AdminUISettingsDetail
        assert resp.response.enabled
        assert resp.response.admin_password is None
        rest_mock.assert_requested(method, uri, body=request)

    def test_put_update_api_password(self, rest_mock: RestClientMock):
        """Test case for put_update_api_password

        """
        method, uri = "put", "/api/api_password"
        request = {"password": "fakepass1234"}
        rest_mock.stub_request(method, uri, {"response": {"password_reset": "ok"}})

        api_client = VNS3Client(
            configuration=Configuration(
                host="0.0.0.0:8000",
                username="api",
                password="password",
                verify_ssl=False,
            )
        )

        resp = api_client.config.put_update_api_password(request)
        assert type(resp) is models.PasswordResetResponse
        assert resp.response.password_reset == "ok"
        rest_mock.assert_requested(method, uri, body=request)

    @pytest.mark.skip(reason="Todo - INSTALL SSL")
    @pytest.mark.licensed
    def test_put_upload_ssl_keypair(self, rest_mock: RestClientMock):
        """Test case for put_upload_ssl_keypair

        """
        pass



import time
from typing import Dict, List

from cohesivenet import VNS3Client, data_types
from cohesivenet.macros import api_operations


def roll_api_password(
    new_password, clients: List[VNS3Client]
) -> data_types.BulkOperationResult:
    """roll_api_password

    Update all passwords for clients

    Arguments:
        new_password {str}
        clients {List[VNS3Client]}

    Returns:
        BulkOperationResult - tuple containing the clients that
        succeeded and the clients that failed with their exceptions
    """

    def _update_password(_client):
        resp = _client.config.put_update_api_password({"password": new_password})
        _client.configuration.password = new_password
        return resp

    return api_operations.__bulk_call_client(
        clients, _update_password, parallelize=True
    )


def disable_uis(clients: List[VNS3Client]):
    """disable_uis

    Disable all UIs for clients

    Arguments:
        clients {List} -- List of VNS3Clients

    Returns:
        BulkOperationResult
    """

    def _disable_ui(_client):
        resp = _client.config.put_update_admin_ui({"enabled": False})
        # required to avoid 502 from api resetting itself
        time.sleep(2.0)
        return resp

    return api_operations.__bulk_call_client(clients, _disable_ui)


def roll_ui_credentials(
    new_credentials: Dict, clients: List[VNS3Client], enable_ui=False
):
    """Update UI credentials to common credentials

    Arguments:
        new_credentials {dict} -- {username: str, password: str}
        clients {List} -- List of VNS3 clients
        enable_ui {Bool} -- whether to enable UI

    Returns:
        BulkOperationResult
    """
    assert "username" in new_credentials, '"username" required in new_credentials arg'
    assert "password" in new_credentials, '"password" required in new_credentials arg'

    def _update_ui_credentials(_client):
        resp = _client.config.put_update_admin_ui(
            {
                "admin_username": new_credentials.get("username"),
                "admin_password": new_credentials.get("password"),
                "enabled": enable_ui,
            }
        )
        # required to avoid 502 from api resetting itself
        time.sleep(2.0)
        return resp

    return api_operations.__bulk_call_client(
        clients, _update_ui_credentials, parallelize=True
    )



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class InitHaRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "uuid": "str",
        "primary_ip": "str",
        "backup_ip": "str",
        "ms_ip": "str",
    }

    attribute_map = {
        "uuid": "uuid",
        "primary_ip": "primary_ip",
        "backup_ip": "backup_ip",
        "ms_ip": "ms_ip",
    }

    def __init__(
        self, uuid=None, primary_ip=None, backup_ip=None, ms_ip=None
    ):  # noqa: E501
        """InitHaRequest - a model defined in OpenAPI"""  # noqa: E501

        self._uuid = None
        self._primary_ip = None
        self._backup_ip = None
        self._ms_ip = None
        self.discriminator = None

        self.uuid = uuid
        self.primary_ip = primary_ip
        self.backup_ip = backup_ip
        self.ms_ip = ms_ip

    @property
    def uuid(self):
        """Gets the uuid of this InitHaRequest.  # noqa: E501


        :return: The uuid of this InitHaRequest.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InitHaRequest.


        :param uuid: The uuid of this InitHaRequest.  # noqa: E501
        :type: str
        """
        if uuid is None:
            raise ValueError(
                "Invalid value for `uuid`, must not be `None`"
            )  # noqa: E501

        self._uuid = uuid

    @property
    def primary_ip(self):
        """Gets the primary_ip of this InitHaRequest.  # noqa: E501


        :return: The primary_ip of this InitHaRequest.  # noqa: E501
        :rtype: str
        """
        return self._primary_ip

    @primary_ip.setter
    def primary_ip(self, primary_ip):
        """Sets the primary_ip of this InitHaRequest.


        :param primary_ip: The primary_ip of this InitHaRequest.  # noqa: E501
        :type: str
        """
        if primary_ip is None:
            raise ValueError(
                "Invalid value for `primary_ip`, must not be `None`"
            )  # noqa: E501

        self._primary_ip = primary_ip

    @property
    def backup_ip(self):
        """Gets the backup_ip of this InitHaRequest.  # noqa: E501

        Controller to be used as backup  # noqa: E501

        :return: The backup_ip of this InitHaRequest.  # noqa: E501
        :rtype: str
        """
        return self._backup_ip

    @backup_ip.setter
    def backup_ip(self, backup_ip):
        """Sets the backup_ip of this InitHaRequest.

        Controller to be used as backup  # noqa: E501

        :param backup_ip: The backup_ip of this InitHaRequest.  # noqa: E501
        :type: str
        """
        if backup_ip is None:
            raise ValueError(
                "Invalid value for `backup_ip`, must not be `None`"
            )  # noqa: E501

        self._backup_ip = backup_ip

    @property
    def ms_ip(self):
        """Gets the ms_ip of this InitHaRequest.  # noqa: E501

        IP of VNS3 MS managing HA  # noqa: E501

        :return: The ms_ip of this InitHaRequest.  # noqa: E501
        :rtype: str
        """
        return self._ms_ip

    @ms_ip.setter
    def ms_ip(self, ms_ip):
        """Sets the ms_ip of this InitHaRequest.

        IP of VNS3 MS managing HA  # noqa: E501

        :param ms_ip: The ms_ip of this InitHaRequest.  # noqa: E501
        :type: str
        """
        if ms_ip is None:
            raise ValueError(
                "Invalid value for `ms_ip`, must not be `None`"
            )  # noqa: E501

        self._ms_ip = ms_ip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InitHaRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.firewall_api import FirewallApi  # noqa: E501
from cohesivenet.rest import ApiException


@pytest.mark.licensed
class TestFirewallApi(object):
    """FirewallApi unit test stubs"""

    def test_delete_firewall_fw_set(self):
        """Test case for delete_firewall_fw_set

        """
        pass

    def test_delete_firewall_rule_by_position(self):
        """Test case for delete_firewall_rule_by_position

        """
        pass

    def test_delete_firewall_rule_by_rule(self):
        """Test case for delete_firewall_rule_by_rule

        """
        pass

    def test_delete_firewall_subgroup(self):
        """Test case for delete_firewall_subgroup

        """
        pass

    def test_get_firewall_fw_sets(self):
        """Test case for get_firewall_fw_sets

        """
        pass

    def test_get_firewall_rule_subgroups(self):
        """Test case for get_firewall_rule_subgroups

        """
        pass

    def test_get_firewall_rules(self):
        """Test case for get_firewall_rules

        """
        pass

    def test_post_create_firewall_rule(self):
        """Test case for post_create_firewall_rule

        """
        pass

    def test_post_create_firewall_subgroup_rule(self):
        """Test case for post_create_firewall_subgroup_rule

        """
        pass

    def test_put_reinitialize_fw_sets(self):
        """Test case for put_reinitialize_fw_sets

        """
        pass

    def test_put_reinitialize_subgroups(self):
        """Test case for put_reinitialize_subgroups

        """
        pass



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class VNS3ControllerPeer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "int",
        "not_set": "bool",
        "_self": "bool",
        "mtu": "int",
        "reachable": "bool",
        "address": "str",
        "overlay_ipaddress": "str",
    }

    attribute_map = {
        "id": "id",
        "not_set": "not_set",
        "_self": "self",
        "mtu": "mtu",
        "reachable": "reachable",
        "address": "address",
        "overlay_ipaddress": "overlay_ipaddress",
    }

    def __init__(
        self,
        id=None,
        not_set=None,
        _self=None,
        mtu=None,
        reachable=None,
        address=None,
        overlay_ipaddress=None,
    ):  # noqa: E501
        """VNS3ControllerPeer - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._not_set = None
        self.__self = None
        self._mtu = None
        self._reachable = None
        self._address = None
        self._overlay_ipaddress = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if not_set is not None:
            self.not_set = not_set
        if _self is not None:
            self._self = _self
        if mtu is not None:
            self.mtu = mtu
        if reachable is not None:
            self.reachable = reachable
        if address is not None:
            self.address = address
        if overlay_ipaddress is not None:
            self.overlay_ipaddress = overlay_ipaddress

    @property
    def id(self):
        """Gets the id of this VNS3ControllerPeer.  # noqa: E501


        :return: The id of this VNS3ControllerPeer.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VNS3ControllerPeer.


        :param id: The id of this VNS3ControllerPeer.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def not_set(self):
        """Gets the not_set of this VNS3ControllerPeer.  # noqa: E501


        :return: The not_set of this VNS3ControllerPeer.  # noqa: E501
        :rtype: bool
        """
        return self._not_set

    @not_set.setter
    def not_set(self, not_set):
        """Sets the not_set of this VNS3ControllerPeer.


        :param not_set: The not_set of this VNS3ControllerPeer.  # noqa: E501
        :type: bool
        """

        self._not_set = not_set

    @property
    def _self(self):
        """Gets the _self of this VNS3ControllerPeer.  # noqa: E501


        :return: The _self of this VNS3ControllerPeer.  # noqa: E501
        :rtype: bool
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """Sets the _self of this VNS3ControllerPeer.


        :param _self: The _self of this VNS3ControllerPeer.  # noqa: E501
        :type: bool
        """

        self.__self = _self

    @property
    def mtu(self):
        """Gets the mtu of this VNS3ControllerPeer.  # noqa: E501


        :return: The mtu of this VNS3ControllerPeer.  # noqa: E501
        :rtype: int
        """
        return self._mtu

    @mtu.setter
    def mtu(self, mtu):
        """Sets the mtu of this VNS3ControllerPeer.


        :param mtu: The mtu of this VNS3ControllerPeer.  # noqa: E501
        :type: int
        """

        self._mtu = mtu

    @property
    def reachable(self):
        """Gets the reachable of this VNS3ControllerPeer.  # noqa: E501


        :return: The reachable of this VNS3ControllerPeer.  # noqa: E501
        :rtype: bool
        """
        return self._reachable

    @reachable.setter
    def reachable(self, reachable):
        """Sets the reachable of this VNS3ControllerPeer.


        :param reachable: The reachable of this VNS3ControllerPeer.  # noqa: E501
        :type: bool
        """

        self._reachable = reachable

    @property
    def address(self):
        """Gets the address of this VNS3ControllerPeer.  # noqa: E501


        :return: The address of this VNS3ControllerPeer.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this VNS3ControllerPeer.


        :param address: The address of this VNS3ControllerPeer.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def overlay_ipaddress(self):
        """Gets the overlay_ipaddress of this VNS3ControllerPeer.  # noqa: E501


        :return: The overlay_ipaddress of this VNS3ControllerPeer.  # noqa: E501
        :rtype: str
        """
        return self._overlay_ipaddress

    @overlay_ipaddress.setter
    def overlay_ipaddress(self, overlay_ipaddress):
        """Sets the overlay_ipaddress of this VNS3ControllerPeer.


        :param overlay_ipaddress: The overlay_ipaddress of this VNS3ControllerPeer.  # noqa: E501
        :type: str
        """

        self._overlay_ipaddress = overlay_ipaddress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VNS3ControllerPeer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
import time

from cohesivenet import Logger
from cohesivenet.exceptions import ApiTypeError, ApiValueError, ApiException


class NetworkEdgePluginsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            from cohesivenet.vns3_client import VNS3Client

            api_client = VNS3Client()
        self.api_client = api_client

    def delete_container(self, uuid, **kwargs):  # noqa: E501
        """delete_container  # noqa: E501

        Delete a container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_container(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteContainerDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_container_with_http_info(uuid, **kwargs)  # noqa: E501

    def delete_container_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """delete_container  # noqa: E501

        Delete a container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_container_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteContainerDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_container" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `delete_container`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers/{uuid}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DeleteContainerDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def delete_container_image(self, uuid, **kwargs):  # noqa: E501
        """delete_container_image  # noqa: E501

        Delete container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_container_image(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param bool force: force operation with cleanup
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DeleteContainerImageDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.delete_container_image_with_http_info(uuid, **kwargs)  # noqa: E501

    def delete_container_image_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """delete_container_image  # noqa: E501

        Delete container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_container_image_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param bool force: force operation with cleanup
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DeleteContainerImageDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid", "force"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_container_image" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `delete_container_image`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []
        if "force" in local_var_params:
            query_params.append(("force", local_var_params["force"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/images/{uuid}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DeleteContainerImageDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_container_logs(self, uuid, lines, **kwargs):  # noqa: E501
        """get_container_logs  # noqa: E501

        Fetch containers log messages  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_logs(uuid, lines, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param int lines: Number of log lines to fetch (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerLogsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_container_logs_with_http_info(
            uuid, lines, **kwargs
        )  # noqa: E501

    def get_container_logs_with_http_info(self, uuid, lines, **kwargs):  # noqa: E501
        """get_container_logs  # noqa: E501

        Fetch containers log messages  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_logs_with_http_info(uuid, lines, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param int lines: Number of log lines to fetch (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerLogsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid", "lines"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_container_logs" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `get_container_logs`"
            )  # noqa: E501
        # verify the required parameter 'lines' is set
        if "lines" not in local_var_params or local_var_params["lines"] is None:
            raise ApiValueError(
                "Missing the required parameter `lines` when calling `get_container_logs`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []
        if "lines" in local_var_params:
            query_params.append(("lines", local_var_params["lines"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers/{uuid}/logs",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerLogsResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_container_system_i_ps(self, **kwargs):  # noqa: E501
        """get_container_system_i_ps  # noqa: E501

        Retrieve IP address list for current container network configuration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_i_ps(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerSystemIPListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_container_system_i_ps_with_http_info(**kwargs)  # noqa: E501

    def get_container_system_i_ps_with_http_info(self, **kwargs):  # noqa: E501
        """get_container_system_i_ps  # noqa: E501

        Retrieve IP address list for current container network configuration  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_i_ps_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerSystemIPListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_container_system_i_ps" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/ip_addresses",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerSystemIPListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_container_system_images(self, **kwargs):  # noqa: E501
        """get_container_system_images  # noqa: E501

        Get list of existing container system images  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_images(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: UUID for resource
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerImageListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_container_system_images_with_http_info(**kwargs)  # noqa: E501

    def get_container_system_images_with_http_info(self, **kwargs):  # noqa: E501
        """get_container_system_images  # noqa: E501

        Get list of existing container system images  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_images_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: UUID for resource
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerImageListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_container_system_images" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "uuid" in local_var_params:
            query_params.append(("uuid", local_var_params["uuid"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/images",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerImageListResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_container_system_running_containers(self, **kwargs):  # noqa: E501
        """get_container_system_running_containers  # noqa: E501

        Provides description information for one or all allocated containers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_running_containers(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool show_all: Boolean for full list output
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RunningContainersDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_container_system_running_containers_with_http_info(
            **kwargs
        )  # noqa: E501

    def get_container_system_running_containers_with_http_info(
        self, **kwargs
    ):  # noqa: E501
        """get_container_system_running_containers  # noqa: E501

        Provides description information for one or all allocated containers  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_running_containers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool show_all: Boolean for full list output
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RunningContainersDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["show_all"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_container_system_running_containers" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "show_all" in local_var_params:
            query_params.append(
                ("show_all", local_var_params["show_all"])
            )  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RunningContainersDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_container_system_status(self, **kwargs):  # noqa: E501
        """get_container_system_status  # noqa: E501

        Retrieve status of container system  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_status(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerSystemStatusDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_container_system_status_with_http_info(**kwargs)  # noqa: E501

    def get_container_system_status_with_http_info(self, **kwargs):  # noqa: E501
        """get_container_system_status  # noqa: E501

        Retrieve status of container system  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_container_system_status_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerSystemStatusDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_container_system_status" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerSystemStatusDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_action_container_system(
        self, container_system_action_request, **kwargs
    ):  # noqa: E501
        """post_action_container_system  # noqa: E501

        Take action on container system  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_action_container_system(container_system_action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ContainerSystemActionRequest container_system_action_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerSystemStatusDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_action_container_system_with_http_info(
            container_system_action_request, **kwargs
        )  # noqa: E501

    def post_action_container_system_with_http_info(
        self, container_system_action_request, **kwargs
    ):  # noqa: E501
        """post_action_container_system  # noqa: E501

        Take action on container system  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_action_container_system_with_http_info(container_system_action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ContainerSystemActionRequest container_system_action_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerSystemStatusDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["container_system_action_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_action_container_system" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'container_system_action_request' is set
        if (
            "container_system_action_request" not in local_var_params
            or local_var_params["container_system_action_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `container_system_action_request` when calling `post_action_container_system`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "container_system_action_request" in local_var_params:
            body_params = local_var_params["container_system_action_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerSystemStatusDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_commit_container(
        self, uuid, commit_container_request, **kwargs
    ):  # noqa: E501
        """post_commit_container  # noqa: E501

        Creates a new container image from a running container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_commit_container(uuid, commit_container_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param CommitContainerRequest commit_container_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateContainerImageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_commit_container_with_http_info(
            uuid, commit_container_request, **kwargs
        )  # noqa: E501

    def post_commit_container_with_http_info(
        self, uuid, commit_container_request, **kwargs
    ):  # noqa: E501
        """post_commit_container  # noqa: E501

        Creates a new container image from a running container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_commit_container_with_http_info(uuid, commit_container_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param CommitContainerRequest commit_container_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateContainerImageResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid", "commit_container_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_commit_container" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `post_commit_container`"
            )  # noqa: E501
        # verify the required parameter 'commit_container_request' is set
        if (
            "commit_container_request" not in local_var_params
            or local_var_params["commit_container_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `commit_container_request` when calling `post_commit_container`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "commit_container_request" in local_var_params:
            body_params = local_var_params["commit_container_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers/{uuid}/commit",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreateContainerImageResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_create_container_image(
        self, create_container_image_request, **kwargs
    ):  # noqa: E501
        """post_create_container_image  # noqa: E501

        Create new container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_container_image(create_container_image_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateContainerImageRequest create_container_image_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CreateImageDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_create_container_image_with_http_info(
            create_container_image_request, **kwargs
        )  # noqa: E501

    def post_create_container_image_with_http_info(
        self, create_container_image_request, **kwargs
    ):  # noqa: E501
        """post_create_container_image  # noqa: E501

        Create new container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_create_container_image_with_http_info(post_create_container_image, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateContainerImageRequest create_container_image_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CreateImageDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["create_container_image_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_create_container_image" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'post_create_container_image' is set
        if (
            "create_container_image_request" not in local_var_params
            or local_var_params["create_container_image_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `post_create_container_image` when calling `post_create_container_image`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "create_container_image_request" in local_var_params:
            body_params = local_var_params["create_container_image_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/images",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CreateImageDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_start_container(self, start_container_request, **kwargs):  # noqa: E501
        """post_start_container  # noqa: E501

        Create (allocate) a new container or start an existing one  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_start_container(start_container_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartContainerRequest start_container_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RunContainerDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_start_container_with_http_info(
            start_container_request, **kwargs
        )  # noqa: E501

    def post_start_container_with_http_info(
        self, start_container_request, **kwargs
    ):  # noqa: E501
        """post_start_container  # noqa: E501

        Create (allocate) a new container or start an existing one  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_start_container_with_http_info(start_container_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StartContainerRequest start_container_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RunContainerDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["start_container_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_start_container" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'start_container_request' is set
        if (
            "start_container_request" not in local_var_params
            or local_var_params["start_container_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `start_container_request` when calling `post_start_container`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "start_container_request" in local_var_params:
            body_params = local_var_params["start_container_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="RunContainerDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_configure_container_system(
        self, update_configure_container_system_request, **kwargs
    ):  # noqa: E501
        """put_configure_container_system  # noqa: E501

        Configures the container network.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_configure_container_system(update_configure_container_system_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateConfigureContainerSystemRequest update_configure_container_system_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ContainerSystemStatusDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_configure_container_system_with_http_info(
            update_configure_container_system_request, **kwargs
        )  # noqa: E501

    def put_configure_container_system_with_http_info(
        self, update_configure_container_system_request, **kwargs
    ):  # noqa: E501
        """put_configure_container_system  # noqa: E501

        Configures the container network.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_configure_container_system_with_http_info(update_configure_container_system_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateConfigureContainerSystemRequest update_configure_container_system_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ContainerSystemStatusDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["update_configure_container_system_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_configure_container_system" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'update_configure_container_system_request' is set
        if (
            "update_configure_container_system_request" not in local_var_params
            or local_var_params["update_configure_container_system_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_configure_container_system_request` when calling `put_configure_container_system`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_configure_container_system_request" in local_var_params:
            body_params = local_var_params["update_configure_container_system_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ContainerSystemStatusDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_edit_container_image(
        self, uuid, update_container_image_request, **kwargs
    ):  # noqa: E501
        """put_edit_container_image  # noqa: E501

        Edits container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_container_image(uuid, update_container_image_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param UpdateContainerImageRequest update_container_image_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: UpdateContainerImageDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_edit_container_image_with_http_info(
            uuid, update_container_image_request, **kwargs
        )  # noqa: E501

    def put_edit_container_image_with_http_info(
        self, uuid, update_container_image_request, **kwargs
    ):  # noqa: E501
        """put_edit_container_image  # noqa: E501

        Edits container image  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_edit_container_image_with_http_info(uuid, update_container_image_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param UpdateContainerImageRequest update_container_image_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(UpdateContainerImageDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid", "update_container_image_request"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_edit_container_image" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `put_edit_container_image`"
            )  # noqa: E501
        # verify the required parameter 'update_container_image_request' is set
        if (
            "update_container_image_request" not in local_var_params
            or local_var_params["update_container_image_request"] is None
        ):
            raise ApiValueError(
                "Missing the required parameter `update_container_image_request` when calling `put_edit_container_image`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_container_image_request" in local_var_params:
            body_params = local_var_params["update_container_image_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/images/{uuid}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UpdateContainerImageDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def put_stop_container(self, uuid, **kwargs):  # noqa: E501
        """put_stop_container  # noqa: E501

        Stops a running container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_stop_container(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: StopContainerDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.put_stop_container_with_http_info(uuid, **kwargs)  # noqa: E501

    def put_stop_container_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """put_stop_container  # noqa: E501

        Stops a running container  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_stop_container_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str uuid: uuid of resource (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(StopContainerDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["uuid"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_stop_container" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'uuid' is set
        if "uuid" not in local_var_params or local_var_params["uuid"] is None:
            raise ApiValueError(
                "Missing the required parameter `uuid` when calling `put_stop_container`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "uuid" in local_var_params:
            path_params["uuid"] = local_var_params["uuid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["basicAuth"]  # noqa: E501

        return self.api_client.call_api(
            "/container_system/containers/{uuid}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="StopContainerDetailResponse",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def assert_container_system_state(self, running, sleep_time=2.0, timeout=30.0):
        """Assert container system is either stopped or running

        Arguments:
            api_client {VNS3Client}
            running {Boolean}

        Keyword Arguments:
            sleep_time {float} (default: {2.0})
            timeout {float} (default: {30.0})

        Raises:
            ApiException:

        Returns:
            Boolean or raises ApiException
        """

        action = "start" if running else "stop"
        expected_running_state = "true" if running else "false"
        expected_in_progress = "starting" if running else "stopping"
        action_data = self.post_action_container_system({"action": action})
        response_state = action_data.response.running.lower()
        if response_state == expected_running_state:
            return True
 
        assert response_state == expected_in_progress, "Unexpected state."

        start_time = time.time()
        while time.time() - start_time < timeout:
            call_data = self.get_container_system_status()
            running_state = call_data.response.running
            if running_state.lower() == expected_running_state:
                return True

            time.sleep(sleep_time)

        raise ApiException(
            "Timeout: Failed to assert container system state running=%s [timeout=%s seconds, host=%s]"
            % (expected_running_state, timeout, self.api_client.host_uri)
        )

    def restart_container_network(self, sleep_time=2.0, timeout=30.0, **kwargs):
        """Restart the container network

        Raises:
            ApiException: Timeout exception

        Returns:
            Boolean
        """
        start_time = time.time()
        self.assert_container_system_state(
            running=False, sleep_time=sleep_time, timeout=timeout
        )
        remaining_time = timeout - (time.time() - start_time)
        self.assert_container_system_state(
            running=True, sleep_time=sleep_time, timeout=remaining_time
        )
        return True

    def wait_for_image_import(self, import_uuid, timeout=60.0, sleep_time=1.0):
        """Poll for image availability with a UUID

        Arguments:
            import_uuid {str} - UUID recieved on import

        Keyword Arguments:
            timeout {float}
            sleep_time {float}

        Raises:
            ApiException: Raise if timeout or UUID does not exist

        Returns:
            Boolean
        """

        start_time = time.time()
        resp_data = self.get_container_system_images(uuid=import_uuid)
        images = resp_data.response.images
        if images is None:
            raise ApiException("No images returned. Is container system running?")
        elif len(images) == 0:
            raise ApiException("Import UUID not found: %s" % import_uuid)

        image_status = images[0].status
        if image_status == "Ready":
            return True

        time.sleep(sleep_time)
        while time.time() - start_time < timeout:
            try:
                resp_data = self.get_container_system_images(uuid=import_uuid)
            except ApiException as e:
                if e.status == 500:
                    Logger.debug(
                        "API server error [500] waiting for image. Likely due to resource contention. Continuing polling.",
                        host=self.api_client.host_uri,
                    )
                    time.sleep(sleep_time)
                    continue
                raise e
            images = resp_data.response.images
            if images is None:
                raise ApiException("No images returned. Is container system running?")
            elif len(images) == 0:
                raise ApiException("Import UUID not found: %s" % import_uuid)

            image_status = images[0].status
            if image_status == "Ready":
                return True
            time.sleep(sleep_time)
        raise ApiException(
            "API timeout [timeout=%s seconds] [Import image uuid=%s]"
            % (timeout, import_uuid)
        )
